import { Component, Input, ViewChild } from "@angular/core";
import { Modal } from "@herbis/ngx-modal";
import { FeedbackService } from "./feedback.service";
import { FeedbackModel } from "./feedback.model";
var FeedbackModalComponent = (function () {
    function FeedbackModalComponent(feedback) {
        this.feedback = feedback;
        feedback.modalComponent = this;
    }
    /**
     * Close this modal.
     */
    FeedbackModalComponent.prototype.closeModal = function () {
        this.modal.close();
        this.feedback.showSendFeedbackButton();
        /* Callback on cancel.*/
        if (this.configuration.onCancel) {
            this.configuration.onCancel();
        }
    };
    /**
     * Hide this modal.
     */
    FeedbackModalComponent.prototype.hideModal = function () {
        this.modal.close();
    };
    /**
     * Open feedback modal.
     */
    FeedbackModalComponent.prototype.openModal = function () {
        this.modal.open();
    };
    /**
     * Show this modal.
     */
    FeedbackModalComponent.prototype.showModal = function () {
        this.modal.open();
    };
    /**
     * Submit the form.
     * @param form the form.
     */
    FeedbackModalComponent.prototype.submit = function (form) {
        var feedbackSubmission = new FeedbackModel();
        feedbackSubmission.form = form;
        feedbackSubmission.screenshots = this.feedback.getScreenshots();
        /* Callback on submit. */
        if (this.configuration.onSubmit) {
            this.configuration.onSubmit(feedbackSubmission);
        }
        else {
            console.warn("No onSubmit callback function configured. It probably should.");
        }
        this.closeModal();
    };
    return FeedbackModalComponent;
}());
export { FeedbackModalComponent };
FeedbackModalComponent.decorators = [
    { type: Component, args: [{
                selector: "ngx-bootstrap-feedback-modal",
                templateUrl: "./feedback-modal.html"
            },] },
];
/** @nocollapse */
FeedbackModalComponent.ctorParameters = function () { return [
    { type: FeedbackService, },
]; };
FeedbackModalComponent.propDecorators = {
    'configuration': [{ type: Input },],
    'modal': [{ type: ViewChild, args: [Modal,] },],
};
//# sourceMappingURL=feedback-modal.component.js.map