import { ChangeDetectorRef } from "@angular/core";
import { FeedbackService } from "./feedback.service";
import { FeedbackConfiguration } from "./feedback-configuration.model";
export declare class FeedbackScreenshotComponent {
    private changeDetection;
    private feedback;
    configuration: FeedbackConfiguration;
    screenshots: string[];
    private canvas;
    private canvasContext;
    private isDrawing;
    private centerX;
    private centerY;
    private highlight;
    private highlightLeft;
    private highlightTop;
    private highlightWidth;
    private highlightHeight;
    private preRenderScrollPosition;
    constructor(changeDetection: ChangeDetectorRef, feedback: FeedbackService);
    /**
     * Add transparent background to canvas.
     */
    private addCanvasAlphaBackground();
    /**
     * Add a screenshot from local machine.
     * @param event the event of selecting image.
     */
    addScreenshot(event: any): void;
    /**
     * Adjust the drawing according to user movement.
     * @param x the x-axis movement position.
     * @param y the y-axis movement position.
     */
    private adjustDrawing(x, y);
    /**
     * Clear all screenshots.
     */
    clearScreenshots(): void;
    /**
     * Create a canvas of the page.
     */
    private createCanvas();
    /**
     * Destroy the page canvas.
     */
    destroyCanvas(): void;
    /**
     * Enter the screenshot mode.
     */
    enterScreenshotMode(): void;
    /**
     * Finish drawing at given position.
     * @param x the x-axis page position to finish at.
     * @param y the y-axis page position to finish at.
     */
    private finishDrawing(x, y);
    /**
     * Process rendered screenshot.
     * @param canvas the canvas.
     */
    private processRenderedScreenshot(canvas);
    /**
     * Redraw the canvas context.
     */
    private redraw();
    /**
     * Remove image at given index.
     * @param index the index in screenshot array.
     */
    remove(index: number): void;
    /**
     * Remove the mouse drawing events.
     */
    private static removeMouseDrawingEvents();
    /**
     * Setup mouse drawing events.
     */
    private setupMouseDrawingEvents();
    /**
     * Start drawing from given position.
     * @param x the x-axis page position to start at.
     * @param y the y-axis page position to start at.
     */
    private startDrawing(x, y);
    /**
     * Capture a screenshot.
     */
    takeScreenshot(): void;
}
