import { Component, Input, ViewChild } from "@angular/core";
import { FeedbackModalComponent } from "./feedback-modal.component";
import { FeedbackService } from "./feedback.service";
var FeedbackComponent = (function () {
    function FeedbackComponent(feedback) {
        this.feedback = feedback;
        this.isHidden = false;
        this.isLoading = false;
        this.isScreenshotMode = false;
        feedback.buttonComponent = this;
    }
    /**
     * Cancel taking of screenshot.
     */
    FeedbackComponent.prototype.cancelScreenshot = function () {
        if (this.configuration.onCancelScreenshot) {
            this.configuration.onCancelScreenshot();
        }
        this.isScreenshotMode = false;
        this.feedbackModal.openModal();
        this.feedback.destroyCanvas();
    };
    /**
     * Clear screenshots.
     */
    FeedbackComponent.prototype.clearScreenshots = function () {
        this.feedback.clearScreenshots();
    };
    /**
     * Get all screenshots taken.
     * @return {string[]} the screenshots as dataUrls.
     */
    FeedbackComponent.prototype.getScreenshots = function () {
        return this.feedback.getScreenshots();
    };
    /**
     * Open feedback modal.
     */
    FeedbackComponent.prototype.openFeedbackModal = function () {
        if (this.configuration.onOpen) {
            this.configuration.onOpen();
        }
        this.isHidden = true;
        this.feedbackModal.openModal();
    };
    /**
     * Take a screenshot.
     */
    FeedbackComponent.prototype.takeScreenshot = function () {
        this.feedback.takeScreenshot();
    };
    return FeedbackComponent;
}());
export { FeedbackComponent };
FeedbackComponent.decorators = [
    { type: Component, args: [{
                selector: "ngx-bootstrap-feedback",
                templateUrl: "./feedback.html"
            },] },
];
/** @nocollapse */
FeedbackComponent.ctorParameters = function () { return [
    { type: FeedbackService, },
]; };
FeedbackComponent.propDecorators = {
    'feedbackModal': [{ type: ViewChild, args: [FeedbackModalComponent,] },],
    'configuration': [{ type: Input },],
};
//# sourceMappingURL=feedback.component.js.map